name = "ec2-cluster"

from pathlib import Path
version_file = Path(__file__).parent/"VERSION"
__version__ = version_file.open('r').read().strip()

from .config.config import ClusterConfig, ClusterConfigValidationError
from .instances.cluster import Cluster
from .shells.control import ClusterShell




import boto3


def get_dlamis(region, ami_type="Ubuntu"):

    assert ami_type in ['Ubuntu', 'Amazon Linux']
    session = boto3.session.Session(region_name=region)
    ec2_client = session.client("ec2")

    # https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Client.describe_images
    response = ec2_client.describe_images(
            ExecutableUsers=[
                'all',
            ],
            Filters=[
                {
                    'Name': 'name',
                    'Values': [
                        f'Deep Learning AMI ({ami_type}) Version *',
                    ]
                },

            ],
            Owners=[
                'amazon',  # 'self' to get AMIs created by you
            ]
    )


    images = []
    for image in response['Images']:
        name = image['Name']
        description = image['Description']
        image_id = image['ImageId']
        snapshot_id = image['BlockDeviceMappings'][0]['Ebs']['SnapshotId']
        version = float(name.split('Version')[1].strip())

        images.append({
            'Name': name,
            'Version': version,
            'Description': description,
            'ImageId': image_id,
            'SnapshotId': snapshot_id
        })


    return sorted(images, key = lambda i: i['Version'], reverse=True)





def get_my_amis(region):

    session = boto3.session.Session(region_name=region)
    ec2_client = session.client("ec2")

    # https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Client.describe_images
    response = ec2_client.describe_images(Owners=['self'])

    images = []
    for image in response['Images']:
        name = image['Name']
        if 'Description' in image.keys():
            description = image['Description']
        else:
            description = "No description available"
        image_id = image['ImageId']
        snapshot_id = image['BlockDeviceMappings'][0]['Ebs']['SnapshotId']

        images.append({
            'Name': name,
            'Description': description,
            'ImageId': image_id,
            'SnapshotId': snapshot_id
        })

    return sorted(images, key = lambda i: i['Name'])




import setuptools
from pathlib import Path

with open("README.md", "r") as fh:
    long_description = fh.read()

version_file = Path(__file__).parent/"ec2_cluster"/"VERSION"
VERSION = version_file.open('r').read().strip()

setuptools.setup(
        name="ec2_cluster",
        version=VERSION,
        author="Armand McQueen",
        author_email="armandmcqueen@gmail.com",
        description="A tool for launching and running commands on multiple EC2 instances",
        long_description=long_description,
        long_description_content_type="text/markdown",
        url="https://github.com/armandmcqueen/ec2-cluster",
        packages=setuptools.find_packages(),
        include_package_data=True,
        classifiers=[
            "Programming Language :: Python :: 3.6",
            "Programming Language :: Python :: 3.7",
            "Programming Language :: Python :: 3.8",
            "Programming Language :: Python :: 3.9",
            "Programming Language :: Python :: 3.10",
        ],
        install_requires=[
            # TODO: We can probably upgrade this right?
            'paramiko<=2.5.1', # Bug in paramiko 2.6.0 (https://github.com/armandmcqueen/ec2-cluster/issues/10)
            'fabric2>2.3.0',
            'boto3',
            'pyyaml',
            'tabulate',
        ],
)
